package handler

import (
	"fmt"
	"git.icechen.cn/monorepo/backend/app/brahma/api/murder/internal/error_process"
	"git.icechen.cn/monorepo/backend/app/brahma/api/murder/internal/model"
	"git.icechen.cn/monorepo/backend/app/brahma/api/murder/internal/service"
	bgm "git.icechen.cn/monorepo/backend/app/brahma/api/murder/internal/util"
	"github.com/gofiber/fiber/v2"
	ctxLogger "github.com/luizsuper/ctxLoggers"
	"go.uber.org/zap"
	"strconv"
)

type (
	TagReq struct {
		Tag *model.Tag `json:"tag" `
	}
	TagCategoriesReq struct {
		Relation *model.TagCategoriesDto `json:"relation" `
	}
)

func CreateTagH(ctx *fiber.Ctx) error {
	m := new(TagReq)
	if err := createTagParamCheck(m, ctx); err != nil {
		ctxLogger.FError(ctx, error_process.BodyParserErr, zap.String("", fmt.Sprintf("%v", err)))
		return ctx.JSON(fail(nil))
	}
	err := service.CreateTag(m.Tag, ctx)
	if err != nil {
		ctxLogger.FError(ctx, error_process.ServiceErr, zap.String("", fmt.Sprintf("%+v", err)))
		return ctx.JSON(fail(nil))
	}
	return ctx.JSON(success(nil))
}

func UpdateTagH(ctx *fiber.Ctx) error {
	m := new(TagReq)
	if err := checkParam(m, ctx); err != nil {
		ctxLogger.FError(ctx, error_process.BodyParserErr, zap.String("", fmt.Sprintf("%v", err)))
		return ctx.JSON(fail(nil))
	}
	err := service.UpdateTag(m.Tag, ctx)
	if err != nil {
		ctxLogger.FError(ctx, error_process.ServiceErr, zap.String("", fmt.Sprintf("%+v", err)))
		return ctx.JSON(fail(nil))
	}
	return ctx.JSON(success(nil))
}

func GetTagH(ctx *fiber.Ctx) error {
	page := ctx.Query("page", "1")
	limit := ctx.Query("size", "10")
	iPage, _ := strconv.Atoi(page)
	iLimit, _ := strconv.Atoi(limit)
	s := ctx.Query("query", "")
	queryMap := bgm.GetQueryMap(s)
	m, num, err := service.GetTag(iPage, iLimit, ctx, queryMap)
	if err != nil {
		ctxLogger.FError(ctx, error_process.ServiceErr, zap.String("", fmt.Sprintf("%+v", err)))
		return ctx.JSON(fail(nil))
	}
	return ctx.JSON(success(&Data{
		Elements: m,
		Total:    num,
	}))
}

func DeleteTagH(ctx *fiber.Ctx) error {
	m := new(TagReq)
	if err := checkParam(m, ctx); err != nil {
		ctxLogger.FError(ctx, error_process.BodyParserErr, zap.String("", fmt.Sprintf("%v", err)))
		return ctx.JSON(fail(nil))
	}
	err := service.DeleteTag(m.Tag, ctx)
	if err != nil {
		ctxLogger.FError(ctx, error_process.ServiceErr, zap.String("", fmt.Sprintf("%+v", err)))
		return ctx.JSON(fail(nil))
	}
	return ctx.JSON(success(nil))
}

// CreateCategoryForTag 为Tag 新增分组
func CreateCategoryForTag(ctx *fiber.Ctx) error {
	m := new(TagCategoriesReq)
	if err := checkParam(m, ctx); err != nil {
		ctxLogger.FError(ctx, error_process.BodyParserErr, zap.String("", fmt.Sprintf("%v", err)))
		return ctx.JSON(fail(nil))
	}
	err := service.CreateCategoryForTag(m.Relation, ctx)
	if err != nil {
		ctxLogger.FError(ctx, error_process.ServiceErr, zap.String("", fmt.Sprintf("%+v", err)))
		return ctx.JSON(fail(nil))
	}
	return ctx.JSON(success(nil))
}

// DeleteCategoryForTag 为Tag 删除分组
func DeleteCategoryForTag(ctx *fiber.Ctx) error {
	m := new(TagCategoriesReq)
	if err := ctx.BodyParser(m); err != nil {
		ctxLogger.FError(ctx, error_process.BodyParserErr, zap.String("", fmt.Sprintf("%+v", err)))
		return ctx.JSON(fail(nil))
	}
	err := service.DelCategoryForTag(m.Relation, ctx)
	if err != nil {
		ctxLogger.FError(ctx, error_process.ServiceErr, zap.String("", fmt.Sprintf("%+v", err)))
		return ctx.JSON(fail(nil))
	}
	return ctx.JSON(success(nil))
}
